@@ -7,30 +7,18 @@ from troposphere.s3 import (
     PublicAccessBlockConfiguration,
     VersioningConfiguration,
 )
+
+from serverless.aws.features.encryption import Encryption
 from serverless.aws.resources import Resource
 
 from serverless.aws.resources.kms import EncryptableResource
 from serverless.service import Identifier
 
 
-class S3Bucket(Resource, EncryptableResource):
+class S3Bucket(Resource):
     def __init__(self, BucketName="${self:service}", domain=None, **kwargs):
         kwargs.setdefault("AccessControl", "Private")
 
-        kwargs.setdefault(
-            "BucketEncryption",
-            BucketEncryption(
-                ServerSideEncryptionConfiguration=[
-                    ServerSideEncryptionRule(
-                        BucketKeyEnabled=True,
-                        ServerSideEncryptionByDefault=ServerSideEncryptionByDefault(
-                            KMSMasterKeyID=self.encryption_key(), SSEAlgorithm="aws:kms"
-                        ),
-                    )
-                ]
-            ),
-        )
-
         kwargs.setdefault(
             "PublicAccessBlockConfiguration",
             PublicAccessBlockConfiguration(
@@ -43,11 +31,25 @@ class S3Bucket(Resource, EncryptableResource):
 
         kwargs.setdefault("VersioningConfiguration", VersioningConfiguration(Status="Enabled"))
 
-        self.bucket = Bucket(title=Identifier(BucketName, safe=True).pascal, **kwargs)
+        bucket = Bucket(title=Identifier(BucketName, safe=True).pascal, **kwargs)
 
-        self.bucket.properties.__setitem__(
+        bucket.properties.__setitem__(
             "BucketName", BucketName + ".${aws:region}." + (domain or "${ssm:/global/primary-domain}")
         )
 
-    def resources(self):
-        return super().resources() + [self.bucket]
+        super().__init__(bucket)
+
+    def configure(self, service):
+        super().configure(service)
+
+        if service.has(Encryption):
+            self.resource.BucketEncryption = BucketEncryption(
+                ServerSideEncryptionConfiguration=[
+                    ServerSideEncryptionRule(
+                        BucketKeyEnabled=True,
+                        ServerSideEncryptionByDefault=ServerSideEncryptionByDefault(
+                            KMSMasterKeyID=EncryptableResource.encryption_key(), SSEAlgorithm="aws:kms"
+                        ),
+                    )
+                ]
+            )
