@@ -41,8 +41,7 @@ class EventDispatcher(Integration):
             resources=[queue.arn()],
         )
 
-        service.provider.environment.envs["EVENTS_DLQ"] = queue.queue.QueueName
-
+        service.provider.environment.envs["EVENTS_DLQ"] = queue.resource.QueueName
         service.provider.iam.apply(Publish(self.event_bus))
 
 
