@@ -3,7 +3,7 @@ from serverless.service.plugins.generic import Generic
 from serverless.service.plugins.iam_roles import IAMRoles
 
 
-class KMSGrant(Generic, EncryptableResource):
+class KMSGrant(Generic):
     def __init__(self, **kwds):
         super().__init__("serverless-kms-grants")
 
@@ -16,12 +16,12 @@ class KMSGrant(Generic, EncryptableResource):
             for fn in service.functions.all():
                 service.custom["kmsGrants"].append(
                     dict(
-                        kmsKeyId="alias/${self:service}-${sls:stage}",
+                        kmsKeyId=EncryptableResource.encryption_alias(),
                         roleName=fn.iam.role,
                     )
                 )
 
         else:
             service.custom["kmsGrants"].append(
-                dict(kmsKeyId="alias/${self:service}-${sls:stage}", roleName=service.provider.iam.role)
+                dict(kmsKeyId=EncryptableResource.encryption_alias(), roleName=service.provider.iam.role)
             )
